@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Matias Fontanini
+ * Copyright (c) 2017, Matias Fontanini
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,11 +27,10 @@
  *
  */
 
-#include <stdexcept>
 #include <cstring>
-#include "bootp.h"
-#include "exceptions.h"
-#include "memory_helpers.h"
+#include <tins/bootp.h>
+#include <tins/exceptions.h>
+#include <tins/memory_helpers.h>
 
 using std::copy;
 
@@ -115,7 +114,7 @@ void BootP::vend(const vend_type& newvend_) {
     vend_ = newvend_;
 }
 
-void BootP::write_serialization(uint8_t* buffer, uint32_t total_sz, const PDU* parent) {
+void BootP::write_serialization(uint8_t* buffer, uint32_t total_sz) {
     OutputMemoryStream stream(buffer, total_sz);
     stream.write(bootp_);
     stream.write(vend_.begin(), vend_.end());
