@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Matias Fontanini
+ * Copyright (c) 2017, Matias Fontanini
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,13 +27,12 @@
  *
  */
 
-#include <stdexcept>
 #include <cstring>
-#include "llc.h"
-#include "stp.h"
-#include "rawpdu.h"
-#include "exceptions.h"
-#include "memory_helpers.h"
+#include <tins/llc.h>
+#include <tins/stp.h>
+#include <tins/rawpdu.h>
+#include <tins/exceptions.h>
+#include <tins/memory_helpers.h>
 
 using Tins::Memory::InputMemoryStream;
 using Tins::Memory::OutputMemoryStream;
@@ -196,7 +195,7 @@ void LLC::clear_information_fields() {
 	information_fields_.clear();
 }
 
-void LLC::write_serialization(uint8_t* buffer, uint32_t total_sz, const Tins::PDU* parent) {
+void LLC::write_serialization(uint8_t* buffer, uint32_t total_sz) {
     OutputMemoryStream stream(buffer, total_sz);
     if (inner_pdu() && inner_pdu()->pdu_type() == PDU::STP) {
         dsap(0x42);
@@ -215,7 +214,7 @@ void LLC::write_serialization(uint8_t* buffer, uint32_t total_sz, const Tins::PD
 			break;
 	}
 
-	for (field_list::const_iterator it = information_fields_.begin(); it != information_fields_.end(); it++) {
+	for (field_list::const_iterator it = information_fields_.begin(); it != information_fields_.end(); ++it) {
         stream.write(it->begin(), it->end());
 	}
 }
