@@ -1,8 +1,8 @@
 #ifndef TINS_DOT11_MGMT_TEST_H
 #define TINS_DOT11_MGMT_TEST_H
 
+#include <tins/dot11/dot11_mgmt.h>
 #include "tests/dot11.h"
-#include "dot11/dot11_mgmt.h"
 
 using Tins::Dot11ManagementFrame;
 
@@ -26,6 +26,7 @@ inline void test_equals_expected(const Dot11ManagementFrame& dot11) {
     EXPECT_EQ(dot11.more_frag(), 0);
     EXPECT_EQ(dot11.retry(), 0);
     EXPECT_EQ(dot11.power_mgmt(), 0);
+    EXPECT_EQ(dot11.more_data(), 0);
     EXPECT_EQ(dot11.wep(), 0);
     EXPECT_EQ(dot11.order(), 0);
     EXPECT_EQ(dot11.duration_id(), 0x234f);
